@@ -16,11 +16,12 @@
 #include <bonobo/bonobo-plug.h>
 #include <bonobo/bonobo-control.h>
 #include <gdk/gdkprivate.h>
+#include <gtk/gtkbox.h>
+#include <gtk/gtkmain.h>
 
 enum {
 	SET_FRAME,
 	ACTIVATE,
-	UNDO_LAST_OPERATION,
 	LAST_SIGNAL
 };
 
@@ -38,10 +39,12 @@ struct _BonoboControlPrivate {
 	gboolean                    active;
 
 	GtkWidget                  *plug;
+	GtkWidget                  *socket;
 	gboolean                    is_local;
 	gboolean                    xid_received;
+	guint                       destroy_idle_id;
 			
-	BonoboUIHandler            *uih;
+	BonoboUIComponent          *ui_component;
 	gboolean                    automerge;
 				   
 	BonoboPropertyBag          *propbag;
@@ -161,35 +164,29 @@ bonobo_control_plug_destroy_cb (GtkWidget *plug,
 static void
 bonobo_control_auto_merge (BonoboControl *control)
 {
-	Bonobo_UIContainer remote_uih;
+	Bonobo_UIContainer remote_container;
 
-	if (control->priv->uih == NULL)
+	if (control->priv->ui_component == NULL)
 		return;
 
-	remote_uih = bonobo_control_get_remote_ui_handler (control);
-	if (remote_uih == CORBA_OBJECT_NIL)
+	remote_container = bonobo_control_get_remote_ui_container (control);
+	if (remote_container == CORBA_OBJECT_NIL)
 		return;
 
-	bonobo_ui_handler_set_container (control->priv->uih, remote_uih);
+	bonobo_ui_component_set_container (
+		control->priv->ui_component, remote_container);
 
-	bonobo_object_release_unref (remote_uih, NULL);
-
-#ifdef STALE_NOT_USED
-	if (control->priv->menus != NULL) {
-		bonobo_ui_handler_menu_add_list (
-			control->priv->uih, "/", control->priv->menus);
-	}
-#endif
+	bonobo_object_release_unref (remote_container, NULL);
 }
 
 
 static void
 bonobo_control_auto_unmerge (BonoboControl *control)
 {
-	if (control->priv->uih == NULL)
+	if (control->priv->ui_component == NULL)
 		return;
 	
-	bonobo_ui_handler_unset_container (control->priv->uih);
+	bonobo_ui_component_unset_container (control->priv->ui_component);
 }
 
 static void
@@ -211,16 +208,6 @@ impl_Bonobo_Control_activate (PortableServer_Servant servant,
 	control->priv->active = activated;
 }
 
-
-static void
-impl_Bonobo_Control_reactivate_and_undo (PortableServer_Servant servant,
-					 CORBA_Environment *ev)
-{
-	BonoboControl *control = BONOBO_CONTROL (bonobo_object_from_servant (servant));
-
-	gtk_signal_emit (GTK_OBJECT (control), control_signals [ACTIVATE], TRUE);
-	gtk_signal_emit (GTK_OBJECT (control), control_signals [UNDO_LAST_OPERATION]);
-}
 	
 static void
 impl_Bonobo_Control_set_frame (PortableServer_Servant servant,
@@ -254,6 +241,32 @@ bonobo_gtk_widget_from_x11_id (guint32 xid)
 	}
 }
 
+static gint
+idle_destroy_socket (gpointer data)
+{
+	BonoboControl *control = BONOBO_CONTROL (data);
+
+	g_return_val_if_fail (control != NULL, FALSE);
+
+	control->priv->destroy_idle_id = 0;
+
+	gtk_widget_destroy (control->priv->socket);
+
+	return FALSE;
+}
+
+
+static void
+remove_destroy_idle (GtkWidget *socket,
+		     BonoboControl *control)
+{
+	if (control->priv->destroy_idle_id != 0) {
+		gtk_idle_remove (control->priv->destroy_idle_id);
+	}
+
+	control->priv->destroy_idle_id = 0;
+}
+
 static void
 impl_Bonobo_Control_set_window (PortableServer_Servant   servant,
 				Bonobo_Control_windowid  id,
@@ -318,6 +331,16 @@ impl_Bonobo_Control_set_window (PortableServer_Servant   servant,
 		socket_parent = local_socket->parent;
 		gtk_widget_hide (local_socket);
 
+		control->priv->socket = local_socket;
+		control->priv->destroy_idle_id = gtk_idle_add (
+			idle_destroy_socket, control);
+
+		gtk_signal_connect (GTK_OBJECT (local_socket),
+				    "destroy",
+				    remove_destroy_idle,
+				    control);
+
+
 		gtk_box_pack_end (GTK_BOX (socket_parent),
 				  control->priv->widget,
 				  TRUE, TRUE, 0);
@@ -460,7 +483,7 @@ bonobo_control_construct (BonoboControl  *control,
 	gtk_object_ref (GTK_OBJECT (widget));
 	gtk_object_sink (GTK_OBJECT (widget));
 
-	control->priv->uih = bonobo_ui_handler_new ();
+	control->priv->ui_component = bonobo_ui_component_new_default ();
 	control->priv->propbag = NULL;
 
 	return control;
@@ -556,6 +579,11 @@ bonobo_control_destroy (GtkObject *object)
 
 	CORBA_exception_init (&ev);
 
+	if (control->priv->destroy_idle_id != 0) {
+		gtk_idle_remove (control->priv->destroy_idle_id);
+	}
+	control->priv->destroy_idle_id = 0;
+
 	if (control->priv->active)
 		Bonobo_ControlFrame_activated (control->priv->control_frame,
 					       FALSE, &ev);
@@ -567,9 +595,9 @@ bonobo_control_destroy (GtkObject *object)
 	/*
 	 * If we have a UIHandler, destroy it.
 	 */
-	if (control->priv->uih != NULL) {
-		bonobo_ui_handler_unset_container (control->priv->uih);
-		bonobo_object_unref (BONOBO_OBJECT (control->priv->uih));
+	if (control->priv->ui_component != NULL) {
+		bonobo_ui_component_unset_container (control->priv->ui_component);
+		bonobo_object_unref (BONOBO_OBJECT (control->priv->ui_component));
 	}
 }
 
@@ -615,7 +643,6 @@ bonobo_control_get_epv (void)
 
 	epv = g_new0 (POA_Bonobo_Control__epv, 1);
 
-	epv->reactivate_and_undo = impl_Bonobo_Control_reactivate_and_undo;
 	epv->activate            = impl_Bonobo_Control_activate;
 	epv->size_allocate       = impl_Bonobo_Control_size_allocate;
 	epv->set_window          = impl_Bonobo_Control_set_window;
@@ -686,18 +713,30 @@ bonobo_control_get_control_frame (BonoboControl *control)
 }
 
 /**
- * bonobo_control_get_ui_handler:
- * @control: A BonoboControl object for which a BonoboUIHandler has been
- * created and set.
- *
- * Returns: The #BonoboUIHandler which @control is using.
- */
-BonoboUIHandler *
-bonobo_control_get_ui_handler (BonoboControl *control)
+ * bonobo_control_get_ui_component:
+ * @control: The control
+ * 
+ * Return value: the associated UI component
+ **/
+BonoboUIComponent *
+bonobo_control_get_ui_component (BonoboControl *control)
 {
 	g_return_val_if_fail (BONOBO_IS_CONTROL (control), NULL);
 
-	return control->priv->uih;
+	return control->priv->ui_component;
+}
+
+void
+bonobo_control_set_ui_component (BonoboControl     *control,
+				 BonoboUIComponent *component)
+{
+	g_return_if_fail (BONOBO_IS_CONTROL (control));
+	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
+
+	if (control->priv->ui_component)
+		bonobo_object_unref (BONOBO_OBJECT (control->priv->ui_component));
+	
+	control->priv->ui_component = component;
 }
 
 /**
@@ -774,18 +813,18 @@ bonobo_control_get_ambient_properties (BonoboControl     *control,
 }
 
 /**
- * bonobo_control_get_remote_ui_handler:
-
+ * bonobo_control_get_remote_ui_container:
+ *
  * @control: A BonoboControl object which is associated with a remote
  * ControlFrame.
  *
  * Returns: The Bonobo_UIContainer CORBA server for the remote BonoboControlFrame.
  */
-Bonobo_Unknown
-bonobo_control_get_remote_ui_handler (BonoboControl *control)
+Bonobo_UIContainer
+bonobo_control_get_remote_ui_container (BonoboControl *control)
 {
 	CORBA_Environment  ev;
-	Bonobo_UIContainer uih;
+	Bonobo_UIContainer ui_component;
 
 	g_return_val_if_fail (BONOBO_IS_CONTROL (control), CORBA_OBJECT_NIL);
 
@@ -794,13 +833,13 @@ bonobo_control_get_remote_ui_handler (BonoboControl *control)
 
 	CORBA_exception_init (&ev);
 
-	uih = Bonobo_ControlFrame_get_ui_handler (control->priv->control_frame, &ev);
+	ui_component = Bonobo_ControlFrame_get_ui_handler (control->priv->control_frame, &ev);
 
 	bonobo_object_check_env (BONOBO_OBJECT (control), control->priv->control_frame, &ev);
 
 	CORBA_exception_free (&ev);
 
-	return uih;
+	return ui_component;
 }
 
 /**
@@ -854,14 +893,6 @@ bonobo_control_class_init (BonoboControlClass *klass)
                                 GTK_TYPE_NONE, 1,
 				GTK_TYPE_BOOL);
 
-	control_signals [UNDO_LAST_OPERATION] =
-                gtk_signal_new ("undo_last_operation",
-                                GTK_RUN_LAST,
-                                object_class->type,
-                                GTK_SIGNAL_OFFSET (BonoboControlClass, undo_last_operation),
-                                gtk_marshal_NONE__NONE,
-                                GTK_TYPE_NONE, 0);
-
 	gtk_object_class_add_signals (object_class, control_signals, LAST_SIGNAL);
 
 	object_class->destroy = bonobo_control_destroy;
