@@ -9,6 +9,7 @@
  * Copyright 1999,2000 Helix Code, Inc.
  */
 #include <config.h>
+#include <stdio.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkmarshal.h>
 #include <gtk/gtktypeutils.h>
@@ -29,7 +30,9 @@ POA_Bonobo_Unknown__vepv bonobo_object_vepv;
  * NB. for a quicker debugging experience simply
  * #define BONOBO_REF_HOOKS
  */
-/* #define BONOBO_REF_HOOKS */
+#if 0
+#	define BONOBO_REF_HOOKS
+#endif
 
 #ifdef BONOBO_REF_HOOKS
 typedef struct {
@@ -162,10 +165,26 @@ bonobo_object_finalize (BonoboAggregateObject *ao)
 	for (l = ao->objs; l; l = l->next) {
 		GtkObject *o = GTK_OBJECT (l->data);
 
-		if (!o || !o->klass || !o->klass->finalize)
-			g_warning ("Serious bonobo object corruption");
-		else
-			o->klass->finalize (o);
+		if (!o)
+			g_error ("Serious bonobo object corruption");
+		else {
+			g_assert (BONOBO_OBJECT (o)->priv->ao != NULL);
+#ifdef BONOBO_REF_HOOKS
+			g_assert (BONOBO_OBJECT (o)->priv->ao->destroyed);
+#endif
+
+			/*
+			 * Disconnect the GTK+ object from the aggregate object
+			 * and unref it so that it is possibly finalized ---
+			 * other parts of GTK+ may still have references to it.
+			 *
+			 * The GTK+ object was already destroy()ed in
+			 * bonobo_object_destroy().
+			 */
+
+			BONOBO_OBJECT (o)->priv->ao = NULL;
+			gtk_object_unref (o);
+		}
 	}
 
 	g_list_free (ao->objs);
@@ -234,13 +253,13 @@ bonobo_object_unref (BonoboObject *object)
 }
 #endif /* bonobo_object_unref */
 
-#ifdef BONOBO_REF_HOOKS
 void
 bonobo_object_trace_refs (BonoboObject *object,
 			  const char   *fn,
 			  int           line,
 			  gboolean      ref)
 {
+#ifdef BONOBO_REF_HOOKS
 	char *indent;
 	BonoboAggregateObject *ao;
 	BonoboDebugRefData *descr;
@@ -303,8 +322,13 @@ bonobo_object_trace_refs (BonoboObject *object,
 			g_free (indent);
 		}
 	}
-}
+#else
+	if (ref)
+		bonobo_object_ref (object);
+	else
+		bonobo_object_unref (object);
 #endif
+}
 
 static void
 impl_Bonobo_Unknown_ref (PortableServer_Servant servant, CORBA_Environment *ev)
@@ -320,6 +344,75 @@ impl_Bonobo_Unknown_ref (PortableServer_Servant servant, CORBA_Environment *ev)
 #endif
 }
 
+/**
+ * bonobo_object_dup_ref:
+ * @object: a Bonobo_Unknown corba object
+ * @ev: Corba_Environment
+ * 
+ *   This function returns a duplicated CORBA Object reference,
+ * it also bumps the ref count on the object. This is ideal to
+ * use in any method returning a Bonobo_Object in a CORBA impl.
+ * 
+ * Return value: duplicated & ref'd corba object reference.
+ **/
+Bonobo_Unknown
+bonobo_object_dup_ref (Bonobo_Unknown     object,
+		       CORBA_Environment *ev)
+{
+	CORBA_Environment tmpev, *rev;
+	Bonobo_Unknown    ans;
+	
+	g_return_val_if_fail (object != CORBA_OBJECT_NIL,
+			      CORBA_OBJECT_NIL);
+
+	if (ev)
+		rev = ev;
+	else {
+		rev = &tmpev;
+		CORBA_exception_init (rev);
+	}
+
+	Bonobo_Unknown_ref (object, rev);
+	ans = CORBA_Object_duplicate (object, rev);
+
+	if (!ev)
+		CORBA_exception_free (&tmpev);
+
+	return ans;
+}
+
+/**
+ * bonobo_object_release_unref:
+ * @object: a Bonobo_Unknown corba object
+ * @ev: Corba_Environment, optional
+ * 
+ *   This function returns releases a CORBA Object reference,
+ * it also decrements the ref count on the bonobo object.
+ * This is the converse of bonobo_object_release_ref
+ * 
+ **/
+void
+bonobo_object_release_unref (Bonobo_Unknown     object,
+			     CORBA_Environment *ev)
+{
+	CORBA_Environment tmpev, *rev;
+
+	g_return_if_fail (object != CORBA_OBJECT_NIL);
+
+	if (ev)
+		rev = ev;
+	else {
+		rev = &tmpev;
+		CORBA_exception_init (rev);
+	}
+
+	Bonobo_Unknown_unref (object, rev);
+	CORBA_Object_release (object, rev);
+
+	if (!ev)
+		CORBA_exception_free (&tmpev);
+}
+
 static void
 impl_Bonobo_Unknown_unref (PortableServer_Servant servant, CORBA_Environment *ev)
 {
@@ -481,10 +574,14 @@ bonobo_object_finalize_real (GtkObject *object)
 	void *servant = bonobo_object->servant;
 	CORBA_Environment ev;
 
+	g_assert (bonobo_object->priv->ao == NULL);
+
 	CORBA_exception_init (&ev);
 
-	if (bonobo_object->corba_objref != CORBA_OBJECT_NIL)
+	if (bonobo_object->corba_objref != CORBA_OBJECT_NIL) {
 		CORBA_Object_release (bonobo_object->corba_objref, &ev);
+		bonobo_object->corba_objref = CORBA_OBJECT_NIL;
+	}
 
 	if (servant) {
 		PortableServer_ObjectId *oid;
@@ -497,16 +594,6 @@ bonobo_object_finalize_real (GtkObject *object)
 	}
 	CORBA_exception_free (&ev);
 
-	/*
-	 * Check for idiots using gtk_object fns
-	 */
-#ifdef BONOBO_REF_HOOKS
-	if (!bonobo_object->priv->ao->destroyed)
-		g_error ("Serious error finalizing only part "
-			 "of a bonobo aggregate object");
-#endif
-
-	bonobo_object->priv->ao = NULL;
 	g_free (bonobo_object->priv);
 
 	bonobo_object_parent_class->finalize (object);
@@ -557,7 +644,8 @@ bonobo_object_usage_error (BonoboObject *object)
 }
 
 static void
-bonobo_object_instance_init (GtkObject *gtk_object)
+bonobo_object_instance_init (GtkObject    *gtk_object,
+			     GtkTypeClass *klass)
 {
 	BonoboObject *object = BONOBO_OBJECT (gtk_object);
 	BonoboAggregateObject *ao;
@@ -579,7 +667,7 @@ bonobo_object_instance_init (GtkObject *gtk_object)
 	{
 		char *indent = g_strnfill (++ref_indent, ' ');
 		g_printerr ("%sCreate %s:[%p] to %d\n", indent,
-			    gtk_type_name (GTK_OBJECT (object)->klass->type),
+			    gtk_type_name (klass->type),
 			    ao, ao->ref_count);
 		g_free (indent);
 
@@ -912,3 +1000,26 @@ bonobo_object_new_from_servant (void *servant)
 
 	return object;
 }
+
+void
+bonobo_object_dump_interfaces (BonoboObject *object)
+{
+	BonoboAggregateObject *ao;
+	GList                 *l;
+
+	g_return_if_fail (BONOBO_IS_OBJECT (object));
+
+	ao = object->priv->ao;
+	
+	fprintf (stderr, "references %d\n", ao->ref_count);
+	for (l = ao->objs; l; l = l->next) {
+		BonoboObject *o = l->data;
+		
+		g_return_if_fail (BONOBO_IS_OBJECT (o));
+
+		if (o->corba_objref && o->corba_objref->object_id)
+			fprintf (stderr, "I/F: '%s'\n", o->corba_objref->object_id);
+		else
+			fprintf (stderr, "I/F: NIL error\n");
+	}
+}
