@@ -27,17 +27,20 @@ typedef struct {
 } BonoboPrint;
 
 typedef struct {
-	BonoboObjectClass parent;
+	BonoboObjectClass    parent;
+	BonoboPrintRenderFn *render;
 } BonoboPrintClass;
 
 POA_Bonobo_Print__epv *bonobo_print_get_epv (void);
 
-extern POA_Bonobo_Print__vepv bonobo_print_vepv;
-
-GtkType         bonobo_print_get_type (void);
-
-BonoboPrint    *bonobo_print_new      (BonoboPrintRenderFn *render,
-				       gpointer             user_data);
+GtkType         bonobo_print_get_type            (void);
+Bonobo_Print    bonobo_print_corba_object_create (BonoboObject *object);
+BonoboPrint    *bonobo_print_construct           (BonoboPrint         *p,
+						  Bonobo_Print         corba_p,
+						  BonoboPrintRenderFn *render,
+						  gpointer             user_data);
+BonoboPrint    *bonobo_print_new                 (BonoboPrintRenderFn *render,
+						  gpointer             user_data);
 
 
 END_GNOME_DECLS
