@@ -427,7 +427,27 @@ bonobo_ui_component_set_tree (BonoboUIComponent *component,
 	bonobo_ui_node_free_string (str);
 }
 
-char *
+void
+bonobo_ui_component_set_translate (BonoboUIComponent  *component,
+				   const char         *path,
+				   const char         *xml,
+				   CORBA_Environment  *ev)
+{
+	BonoboUINode *node;
+
+	if (!xml)
+		return;
+
+	node = bonobo_ui_node_from_string (xml);
+
+	bonobo_ui_util_translate_ui (node);
+
+	bonobo_ui_component_set_tree (component, path, node, ev);
+
+	bonobo_ui_node_free (node);
+}
+
+CORBA_char *
 bonobo_ui_component_get (BonoboUIComponent *component,
 			 const char        *path,
 			 gboolean           recurse,
@@ -436,7 +456,7 @@ bonobo_ui_component_get (BonoboUIComponent *component,
 	return GET_CLASS (component)->xml_get (component, path, recurse, ev);
 }
 
-static char *
+static CORBA_char *
 impl_xml_get (BonoboUIComponent *component,
 	      const char        *path,
 	      gboolean           recurse,
@@ -485,6 +505,8 @@ bonobo_ui_component_get_tree (BonoboUIComponent  *component,
 
 	node = bonobo_ui_node_from_string (xml);
 
+	CORBA_free (xml);
+
 	if (!node)
 		return NULL;
 
@@ -700,7 +722,12 @@ bonobo_ui_component_set_prop (BonoboUIComponent  *component,
 			      const char         *value,
 			      CORBA_Environment  *opt_ev)
 {
-	GET_CLASS (component)->set_prop (component, path, prop, value, opt_ev);
+	if (prop && (!strcmp (prop, "label") || !strcmp (prop, "tip"))) {
+		char *encoded = bonobo_ui_util_encode_str (value);
+		GET_CLASS (component)->set_prop (component, path, prop, encoded, opt_ev);
+		g_free (encoded);
+	} else
+		GET_CLASS (component)->set_prop (component, path, prop, value, opt_ev);
 }
 
 static void
@@ -741,7 +768,23 @@ bonobo_ui_component_get_prop (BonoboUIComponent *component,
 			      const char        *prop,
 			      CORBA_Environment *opt_ev)
 {
-	return GET_CLASS (component)->get_prop (component, path, prop, opt_ev);
+	char *txt;
+
+	txt = GET_CLASS (component)->get_prop (component, path, prop, opt_ev);
+	
+	if (prop && (!strcmp (prop, "label") || !strcmp (prop, "tip"))) {
+		char *decoded;
+		gboolean err;
+
+		decoded = bonobo_ui_util_decode_str (txt, &err);
+		if (err)
+			g_warning ("Encoding error getting prop '%s' at path '%s'",
+				   prop, path);
+		g_free (txt);
+
+		return decoded;
+	} else
+		return txt;
 }
 
 static gchar *
@@ -821,13 +864,20 @@ bonobo_ui_component_set_status (BonoboUIComponent *component,
 				const char        *text,
 				CORBA_Environment *opt_ev)
 {
-	char *str;
+	if (text == NULL ||
+	    text [0] == '\0') { /* Remove what was there to reveal other msgs */
+		bonobo_ui_component_rm (component, "/status/main/*", opt_ev);
+	} else {
+		char *str, *encoded;
 
-	g_return_if_fail (text != NULL);
-
-	str = g_strdup_printf ("<item name=\"main\">%s</item>", text);
-
-	bonobo_ui_component_set (component, "/status", str, opt_ev);
+		encoded = bonobo_ui_util_encode_str (text);
+		str = g_strdup_printf ("<item name=\"main\">%s</item>", encoded);
+		g_free (encoded);
+		
+		bonobo_ui_component_set (component, "/status", str, opt_ev);
+		
+		g_free (str);
+	}
 }
 
 void
