@@ -33,10 +33,17 @@
 static GtkBinClass *parent_class = NULL;
 
 struct _BonoboUIToolbarItemPrivate {
-	/* Whether this button wants to have a label when the toolbar style is
+	/* Whether this item wants to have a label when the toolbar style is
            `BONOBO_UI_TOOLBAR_STYLE_PRIORITY_TEXT'.  */
 	gboolean want_label;
 
+	/* Whether this item wants to be expanded to all the available
+           width/height.  */
+	gboolean expandable;
+
+	/* if set, pack this item on the right side of the toolbar */
+	gboolean pack_end;
+
 	/* Orientation for this item.  */
 	GtkOrientation orientation;
 
@@ -92,7 +99,6 @@ impl_size_request (GtkWidget *widget,
 	toolbar_item = BONOBO_UI_TOOLBAR_ITEM (widget);
 	priv = toolbar_item->priv;
 
-
 	border_width = GTK_CONTAINER (widget)->border_width;
 	requisition_return->width  = border_width;
 	requisition_return->height = border_width;
@@ -103,9 +109,8 @@ impl_size_request (GtkWidget *widget,
 
 	gtk_widget_size_request (child, &child_requisition);
 
-	if (child_requisition.width < priv->minimum_width) {
+	if (child_requisition.width < priv->minimum_width)
 		child_requisition.width = priv->minimum_width;
-	}
 	
 	requisition_return->width  += child_requisition.width;
 	requisition_return->height += child_requisition.height;
@@ -262,9 +267,11 @@ init (GtkObject *object)
 
 	priv = g_new (BonoboUIToolbarItemPrivate, 1);
 
-	priv->want_label  = FALSE;
-	priv->orientation = GTK_ORIENTATION_HORIZONTAL;
-	priv->style       = BONOBO_UI_TOOLBAR_ITEM_STYLE_ICON_AND_TEXT_VERTICAL;
+	priv->want_label    = FALSE;
+	priv->orientation   = GTK_ORIENTATION_HORIZONTAL;
+	priv->style         = BONOBO_UI_TOOLBAR_ITEM_STYLE_ICON_AND_TEXT_VERTICAL;
+	priv->expandable    = FALSE;
+	priv->pack_end	    = FALSE;
 	priv->minimum_width = 0;
 	
 	toolbar_item->priv = priv;
@@ -415,7 +422,66 @@ bonobo_ui_toolbar_item_get_want_label (BonoboUIToolbarItem *item)
 	return priv->want_label;
 }
 
-
+void
+bonobo_ui_toolbar_item_set_expandable (BonoboUIToolbarItem *item,
+				       gboolean expandable)
+{
+	BonoboUIToolbarItemPrivate *priv;
+
+	g_return_if_fail (item != NULL);
+	g_return_if_fail (BONOBO_IS_UI_TOOLBAR_ITEM (item));
+
+	priv = item->priv;
+
+	if ((priv->expandable && expandable) || (! priv->expandable && ! expandable))
+		return;
+
+	priv->expandable = expandable;
+	gtk_widget_queue_resize (GTK_WIDGET (item));
+}
+
+gboolean
+bonobo_ui_toolbar_item_get_expandable (BonoboUIToolbarItem *item)
+{
+	BonoboUIToolbarItemPrivate *priv;
+
+	g_return_val_if_fail (item != NULL, FALSE);
+	g_return_val_if_fail (BONOBO_IS_UI_TOOLBAR_ITEM (item), FALSE);
+
+	priv = item->priv;
+	return priv->expandable;
+}
+
+void
+bonobo_ui_toolbar_item_set_pack_end (BonoboUIToolbarItem *item,
+				       gboolean pack_end)
+{
+	BonoboUIToolbarItemPrivate *priv;
+
+	g_return_if_fail (item != NULL);
+	g_return_if_fail (BONOBO_IS_UI_TOOLBAR_ITEM (item));
+
+	priv = item->priv;
+
+	if ((priv->pack_end && pack_end) || (! priv->pack_end && ! pack_end))
+		return;
+
+	priv->pack_end = pack_end;
+	gtk_widget_queue_resize (GTK_WIDGET (item));
+}
+
+gboolean
+bonobo_ui_toolbar_item_get_pack_end (BonoboUIToolbarItem *item)
+{
+	BonoboUIToolbarItemPrivate *priv;
+
+	g_return_val_if_fail (item != NULL, FALSE);
+	g_return_val_if_fail (BONOBO_IS_UI_TOOLBAR_ITEM (item), FALSE);
+
+	priv = item->priv;
+	return priv->pack_end;
+}
+
 void
 bonobo_ui_toolbar_item_activate (BonoboUIToolbarItem *item)
 {
